@@ -45,6 +45,7 @@ struct node_t {
     	double rtt;
 	int    gap;	/* original value */
 	int    gap1; 	/* after sanity check */
+	int    bw_flag;
 	char   ip_str[16];
 	char   as[128];
 	char   hostname[256];
@@ -53,7 +54,6 @@ struct node_t {
 			   in_node */
 };
 
-
 struct rec_t {
     	double opt;
 	double ls; 
@@ -71,6 +71,10 @@ struct node_t node[MAX_PATH]; 		/* used for processing */
 int in_path_len = 0;
 int path_len = 0;
 
+/* default values are set here, will be from commmand line */
+int pkt_size = 500; 
+int pkt_num = 60;
+
 char * selected[MAX_PATH];
 
 int get_line(char items[MAX_ITEM_NUM][LINE_SIZE]) 
@@ -421,11 +425,22 @@ void dump()
 	char num_str[2];
 	int num_choke = 0;
 
+	double bw;
+	char bw_str[3];
+
 	j = 0;
 	for (i=0; i<in_path_len; i++) {
 	    if (i == node[j].index) {
 		printf("%-5d %-5d ", in_node[i].gap, node[j].gap1);
 
+		if (j==0)
+		    /* first hop is always considered as an upper bound */
+		    node[j].bw_flag = 1; 
+		else
+		    /* assume this is not a choke point yet, most of hops are
+		     * lower bounds */
+	    	    node[j].bw_flag = -1;
+
 		/* the choke nodes */
 		if (selected[j] != NULL) {
 		    printf("%s ", selected[j]);
@@ -436,18 +451,35 @@ void dump()
 		    conf_i = atoi(num_str) - 1; 
 		    if (j==0) 
 		    	conf[conf_i] = 1;
-		    else
+		    else {
 		    	conf[conf_i] = abs(1/(double)node[j-1].gap1 - 1/(double)node[j].gap1) / (1/(double)node[j-1].gap1);
-		}
-		else 
+
+			if (node[j].gap1 < node[j-1].gap1)
+			    node[j].bw_flag = 0;
+			else
+			    node[j].bw_flag = 1; /* upper bound */
+		    }
+		} else 
 		    printf("    ");
+
+		/* this need to be further processed by script/get-summary.pl, 
+		 * since we don't know pkt_num & pkt_size */
+		bw = ((double) pkt_size * pkt_num * 8) / ((double) node[j].gap1); 
+		if (node[j].bw_flag > 0)
+		    sprintf(bw_str, "ub");
+		else if (node[j].bw_flag < 0)
+		    sprintf(bw_str, "lb");
+		else
+		    sprintf(bw_str, "uk");
 	    } else {
 		printf("%-5d %-5d     ", in_node[i].gap, in_node[i].gap1);
+		bw = 0; 
+		sprintf(bw_str, "uk");
 	    }
 
-	    printf("%7.3f %-15s %6s %s\n", 
-		    in_node[i].rtt, in_node[i].ip_str, 
-		    in_node[i].as, in_node[i].hostname);
+	    printf("%7.3f %-15s %6s %7.3f %s %s\n",
+		    in_node[i].rtt, in_node[i].ip_str, in_node[i].as, 
+		    bw, bw_str, in_node[i].hostname);
 
 	    if (i == node[j].index && j < path_len-1) 
 		j++;
@@ -463,7 +495,7 @@ void dump()
 
 int main(int argc, char * argv[]) 
 {
-    	if (argc != 2) {
+    	if (argc != 4) {
 	    printf("wrong command line\n");
 	    exit(0);
 	}
@@ -473,6 +505,9 @@ int main(int argc, char * argv[])
 	    exit(1);
 	}
 
+	pkt_size = atoi(argv[2]);
+	pkt_num = atoi(argv[3]);
+
     	read_in();
 
 	if (sanity_check()) 
