@@ -404,6 +404,7 @@ void dump_route()
 {
     	int i, j, k1, k2;
 	double rtt1, rtt2, rtt;
+	double bw;
 	char hostname[MAXHOSTNAMELEN], ipstr[16], my_ipstr[16];
 	uint32_t cur_ip;
 
@@ -447,9 +448,20 @@ void dump_route()
 			printf(" %c", selected[j][1]);
 		    else
 			printf(" %c", '.');
+
+		    bw = ((double)udp_probing_size * udp_pkt_num * 8) / (1000000 * (double)ip_path[i].avg_gap);
+		    if (node[j].bw_flag > 0)
+			printf(" %7.3f ub", bw);
+		    else if (node[j].bw_flag < 0)
+			printf(" %7.3f lb", bw);
+		    else 
+			printf(" %7.3f uk", 0.0);
+
 		    j ++;
-		} else
-		    printf(" %6d .", 0);
+
+		} else {
+		    printf(" %6d . %7.3f uk", 0, 0.0);
+		}
 	    }
 	    /* IP -> DNS name lookup */
 	    if (dns_lookup)
@@ -539,7 +551,7 @@ void recv_pkts(int last)
 			continue;
 
 		    /* if "-c" is specified, rtt_i could exceed MAX_RTT_NUM */
-		    if (rtt_i < MAX_RTT_NUM && len == 60) {
+		    if (rtt_i < MAX_RTT_NUM) {
 			memcpy(rtt_rec[rtt_i], buffer, len);
 			rtt_arr_time[rtt_i] = get_time();
 			pre_time = rtt_arr_time[rtt_i];
