@@ -5,7 +5,7 @@
 # where the source is installed
 ##############################################################################
 
-root=/usr0/hnn/eprobe/src/release-v1.0
+root=/usr0/hnn/eprobe/src/pathneck-1.3-tobe
 
 ####################################################
 #	Optional configuration below
